@@ -1093,6 +1093,32 @@ class TransferCoefficient(etree.ElementBase):
 class IntermediateExchange(CustomExchange):
     """Comprises intermediate product and waste inputs and outputs for the activity."""
 
+    INPUT_GROUP_MAP: Dict[int, str] = {
+        1: "Materials/Fuels",
+        2: "Electricity/Heat",
+        3: "Services",
+        5: "From Technosphere (unspecified)",
+    }
+
+    OUTPUT_GROUP_MAP: Dict[int, str] = {
+        0: "ReferenceProduct",
+        2: "By-product",
+        3: "MaterialForTreatment",
+        5: "Stock Additions",
+    }
+
+    _inputGroup = create_element_text_v2("inputGroup", int)
+    """int: Indicates the kind of input flow. The codes are: 1=Materials/Fuels,
+    2=Electricity/Heat, 3=Services, 5=From Technosphere (unspecified). For each
+    exchange only an inputGroup or outputGroup shall exist. This indicates the
+    direction of the flow."""
+
+    _outputGroup = create_element_text_v2("outputGroup", int)
+    """int: Indicates the kind of output flow. The codes are: 0=ReferenceProduct,
+    2=By-product, 3=MaterialForTreatment, 5=Stock Additions. For each exchange only
+    an inputGroup or outputGroup shall exist. This indicates the direction of the
+    flow."""
+
     productionVolumeComments = create_attribute_list_v2("productionVolumeComments", str)
     """lits[str]: A general comment can be made on the data source, assumptions and
     calculations for the production volume data."""
@@ -1169,6 +1195,39 @@ class IntermediateExchange(CustomExchange):
     written communication and questionnaries ('sourceType'=4, 5, 6, 7) the name of the
     communicating person is"""
 
+    @property
+    def _inputGroupStr(self) -> str:
+        """String representation for _inputGroup. See _inputGroup for explanations.
+        1=Materials/Fuels, 2=Electricity/Heat, 3=Services, 5=From Technosphere
+        (unspecified)."""
+        return self.INPUT_GROUP_MAP[self._inputGroup]
+
+    @property
+    def _outputGroupStr(self) -> str:
+        """String representation for _outputGroup. See _outputGroup for explanations.
+        0=ReferenceProduct, 2=By-product, 3=MaterialForTreatment, 5=Stock Additions."""
+        return self.OUTPUT_GROUP_MAP[self._outputGroup]
+
+    @property
+    def group(self) -> List[int]:
+        """Choice between _inputGroup and _outputGroup. Check their documentation
+        for more information."""
+        return (
+            self._inputGroup
+            if self.find("inputGroup", self.nsmap) is not None
+            else self._outputGroup
+        )
+
+    @property
+    def groupStr(self) -> List[str]:
+        """Choice between _inputGroupStr and _outputGroupStr. Check their
+        documentation for more information."""
+        return (
+            self._inputGroupStr
+            if self.find("inputGroup", self.nsmap) is not None
+            else self._outputGroupStr
+        )
+
     @property
     def productionVolumeUncertainties(self) -> List["Uncertainty"]:
         """Uncertainty information in the form of distribution functions and their
@@ -1185,13 +1244,13 @@ class ElementaryExchange(CustomExchange):
     """Comprises elementary inputs and outputs (exchanges with the environment)
     for the activity."""
 
-    inputGroup = create_element_text_v2("inputGroup", int)
+    _inputGroup = create_element_text_v2("inputGroup", int)
     """int: Indicates the kind of input flow. The codes are: 4=From Environment
     For each exchange only an inputGroup or outputGroup shall exist. This
     indicates the direction of the flow. This field is the equivalent of field
     1500 with a different set of valid values."""
 
-    outputGroup = create_element_text_v2("outputGroup", int)
+    _outputGroup = create_element_text_v2("outputGroup", int)
     """int: Indicates the kind of output flow. The codes are: 4=ToEnvironment
     For each exchange only an inputGroup or outputGroup shall exist. This
     indicates the direction of the flow. This field is the equivalent of field
@@ -1218,17 +1277,37 @@ class ElementaryExchange(CustomExchange):
         return get_element(self, "compartment")
 
     @property
-    def inputGroupStr(self) -> str:
-        """String representation for inputGroup. See inputGroup for
+    def _inputGroupStr(self) -> str:
+        """String representation for _inputGroup. See _inputGroup for
         explanations. 4=FromEnvironment"""
         return "FromEnvironment"
 
     @property
-    def outputGroupStr(self) -> str:
-        """String representation for outputGroup. See outputGroup for
+    def _outputGroupStr(self) -> str:
+        """String representation for _outputGroup. See _outputGroup for
         explanations. 4=ToEnvironment"""
         return "ToEnvironment"
 
+    @property
+    def group(self) -> List[int]:
+        """Choice between _inputGroup and _outputGroup. Check their documentation
+        for more information."""
+        return (
+            self._inputGroup
+            if self.find("inputGroup", self.nsmap) is not None
+            else self._outputGroup
+        )
+
+    @property
+    def groupStr(self) -> List[str]:
+        """Choice between _inputGroupStr and _outputGroupStr. Check their
+        documentation for more information."""
+        return (
+            self._inputGroupStr
+            if self.find("inputGroup", self.nsmap) is not None
+            else self._outputGroupStr
+        )
+
 
 class Parameter(etree.ElementBase):
     """Comprises all parameters of the activity."""
