@@ -289,24 +289,20 @@ def test_parse_file_v1_technology(eco_spold: EcoSpold) -> None:
 def test_parse_file_v1_time_period(eco_spold: EcoSpold) -> None:
     """It parses attributes correctly."""
     text = "Year when reference used for this inventory was published."
-    startYear = "1999"
-    startYearMonth = ""
-    startDate = ""
-    endYear = "1999"
-    endYearMonth = ""
-    endDate = ""
+    startDate = datetime(1999, 1, 1)
+    endDate = datetime(1999, 1, 1)
+    modifiedEndDate = datetime(2000, 3, 4)
     processInformation = eco_spold.datasets[0].metaInformation.processInformation
     timePeriod = processInformation.timePeriod
 
     assert timePeriod.dataValidForEntirePeriod
     assert timePeriod.text == text
-    assert timePeriod.startYear == startYear
-    assert timePeriod.startYearMonth == startYearMonth
     assert timePeriod.startDate == startDate
-    assert timePeriod.endYear == endYear
-    assert timePeriod.endYearMonth == endYearMonth
     assert timePeriod.endDate == endDate
 
+    timePeriod.endDate = modifiedEndDate
+    assert timePeriod.endDate == modifiedEndDate
+
 
 def test_parse_file_v1_dataset_information(eco_spold: EcoSpold) -> None:
     """It parses attributes correctly."""
